#

##

###

###

###

##

##

    	genetics

    	summary

    		genome
    			genome:squeeze:gene:sequence::blockchain:aggregate:block:tx

    		organisms
    			vibes::keys

    		organs
    			node & wallet

    	technology possibilities

    		possibilities:
    			[ ] mongodb
    			[ ] rethinkdb
    			[ ] postgres
    			[ ] lmdb

    	important
    		{ divergence, hard forks }
    			This is when a room becomes two or more rooms.